system.System

Define a measurement setup/system.

Usage

system.System(name=None)

It is mostly defined by the individual Parameters (stored in parameters) that are used in the system as well as the list of devices stored in devs. Additionally, it provides functions to set, trigger and read the individual parameters using the specifications provided there. Finally, it defines the set, query and reset function, which are used to open and initialize the devices, query the device configuration/status and return the system to a defined state, respectively.

Attributes

parameters: list

Contains the individual parameters that make up the system.

columns: list

Contains the column names extracted from the individual parameters.

units: list

Contains the units extracted from the individual parameters.

dtypes: list

Contains the dtypes extracted from the individual parameters.

default_values: list

Contains the default_values extracted from the individual parameters.

chunks: list

Contains the chunks extracted from the individual parameters.

devs: dict

Contains the individual devices that belong to the system.

dcdata: dict

Contains telemetry according to the Dublin Core specification that can be used to generate specific header information. see VALID_META_KEYS

system_config_params: dict

Contains the definition for custom device queries to read the configuration. Keys match the device names in .devs.

name: str or None
Optional instance name. ControlWindow binds a valid name here as the subsystem’s accessor name after merging.