system.System.set()

Handle device opening/initialization.

Usage

system.System.set(
    *args,
    **kwargs,
)

For format of devs refer to add_dev

Parameters

*args: tuple

Arguments that can be used here, currently not used.

**kwargs: dict
Keyword arguments that can be used here, currently not used.