system.System.reset()
General reset function for deinitialization of system.
Usage
system.System.reset(
*args,
**kwargs,
)Clears the read buffer of the instrument. The device will be left open and initialized unless the system is closed or deleted.
Parameters
*args: tuple-
Arguments that can be used here, currently not used.
**kwargs: dict- Keyword arguments that can be used here, currently not used.